<?php
namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Request\Filter;
use Doctrine\ORM\EntityManager;
use Teknisa\Model\Util\NovoCodigo;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\DataSet;

class MetasController extends TeknisaCrud {
    protected $dataSourceName = 'crm_perfilmetas';
    protected $connection;
    
    public function __construct($crudService, ParameterBag $parameterBag, EntityManager $entityManager) {
		$this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->connection = $entityManager->getConnection();
        parent::__construct($crudService, $parameterBag);
	}
    
    public function save(Request $request, Response $response) {
        $this->connection->beginTransaction();
        
        try {
            $this->dataSourceName = 'crm_perfilmetas';
            $rows = $request->getDataSet()->getRows();
            foreach($rows as $row) {
                $row['NRPERFILMETAS'] = NovoCodigo::geraCodigo($row['NRORG'], "NRPERFILMETAS", 1, 10, false, true);
            }
            
            parent::save($request, $response);
            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollBack();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function saveOperador(Request $request, Response $response) {
        $this->connection->beginTransaction();
        
        try {
            $this->dataSourceName = 'crm_meta_operador';
            $rows = $request->getDataSet()->getRows();
            
            foreach($rows as $row) {
                $row['NROPERMETA'] = NovoCodigo::geraCodigo($row['NRORG'], "NROPERMETA", 1, 10, false, true);
            }
            
            parent::save($request, $response);
            $this->connection->commit();
        } catch(\Exception $e) {
            $this->connection->rollBack();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function getOperadorUnico(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = 'oper_exclusivo_metas';
        $this->parameterBagColumns = array('P_TIPOMETA','IDTPOPERADOR','NRREVENDA');
        parent::find($request, $response);
    }
    
    public function deleteOperadores(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = 'crm_meta_operador';
        parent::find($request, $response);
        $rows = $response->getDataSets()[0]->getRows();
        $dataSet = new DataSet($this->dataSourceName, $rows);
        $this->crudService->delete($response, $dataSet);
    }
    
}