<?php

namespace Teknisa\CRM\Controller;

use Teknisa\CRM\Controller\TeknisaCrud;
use Zeedhi\Framework\DataSource\ParameterBag;
use Teknisa\CRM\Controller\ReplicacaoParceiroController as Replicacao;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Teknisa\Model\Util\NovoCodigo;

class ger45000ProspectController extends TeknisaCrud
{

    protected $dataSourceName = 'prospect_hierarquiaPerfilDeAcesso';
    protected $parameterBagColumns = array('P_CRM_NRORGTRAB', 'P_NRPARCNEGOCIO', 'IDATIVO', 'IDTPOPERADOR', "NRREVENDA", "NRPARCRESPROSP", "NMRAZSOCPROS");

    protected $newCode;
    protected $environment;
    protected $entityManager;
    protected $connection;
    protected $prospectService;
    protected $parceiroService;
    protected $util;

    public function __construct(
        $crudService,
        $parameterBag,
        $entityManager,
        $newCode,
        $environment,
        $prospectService,
        $parceiroService,
        Replicacao $replicacao,
        $controlerNovaTarefa,
        $util
    ) {

        $this->connection                 = $entityManager->getConnection();
        $this->newCode                    = $newCode;
        $this->entityManager              = $entityManager;
        $this->environment                = $environment;
        $this->prospectService            = $prospectService;
        $this->replicacao                 = $replicacao;
        $this->controlerNovaTarefa        = $controlerNovaTarefa;
        $this->util                       = $util;

        parent::__construct($crudService, $parameterBag);
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response)
    {
        $tipoOperador = $this->util->findFilterValue($request, 'IDTPOPERADOR');
        $operador = $this->util->findFilterValue($request, 'NRPARCRESPROSP');
        $razSoc   = $this->util->findFilterValue($request, 'NMRAZSOCPROS');
        $nomFant  = $this->util->findFilterValue($request, 'NMFANTPROS');
        $inscJur  = $this->util->findFilterValue($request, 'NRINSJURPROS');
        $parcfiltro = $this->util->findFilterValue($request, 'NRPARCNEGOCIO');

        if ($tipoOperador === 'R') {
            $this->dataSourceName = 'prospect_hierarquiaPerfilDeAcesso_revenda';
        } else if ($tipoOperador != 'R' && !empty($operador)) {
            $this->dataSourceName = 'prospect_hierarquiaPerfilDeAcesso';
        } else {
            $this->dataSourceName = 'prospect_hierarquiaPerfilDeAcesso_full';
        }

        if (!empty($operador) || !empty($razSoc) || !empty($nomFant) || !empty($inscJur) || !empty($parcfiltro)) {
            parent::find($request, $response);
        }

        $this->dataSourceName = 'prospect_hierarquiaPerfilDeAcesso';
    }

    public function save(DTO\Request $request, DTO\Response $response)
    {
        try {
            $this->connection->beginTransaction();

            foreach ($request->getDataSet()->getRows() as &$row) {
                $row['CDOPERRESPONSAVEL'] = $this->prospectService->getCdOperador($row['NRPARCRESPROSP']);
                $row['NRPARCRESP'] = $row['NRPARCRESPROSP'];
                if ($row['__is_new']) {
                    $row["CDTIPOPARCEIRO"] = "PROSPECT";
                    if ($row['IDTPIJURPROS'] === 'F') {
                        $row['TIPOINSC'] = 'CPF';
                    } elseif ($row['IDTPIJURPROS'] === 'J') {
                        $row['TIPOINSC'] = 'CNPJ';
                    } else {
                        $row['TIPOINSC'] = 'LIVRE';
                    }
                    $row['NMFANTPROS'] = empty($row['NMFANTPROS']) ? $row['NMRAZSOCPROS'] : $row['NMFANTPROS'];
                    $row['ISCPF'] = ($row['IDTPIJURPROS'] === 'F') ? 'S' : 'N';
                    $parcCriado = $this->prospectService->verificaParceiro($row);
                    if (empty($parcCriado)) {
                        $row['CDPROSPECT'] = $this->newCode->getCodeByTableName("PROSPECT", $row["NRORG"]);
                        $row['NRPARCNEGOCIO'] = $this->newCode->getCodeByTableName("PARCNEGOCIO", $row["NRORG"]);
                        $row['NRSEQCONTATO'] = $this->newCode->getCodeByTableName("NRSEQCONTATO", $row["NRORG"]);
                        $row['NRPARCERIA'] = NovoCodigo::geraCodigo($row["NRORG"], "PARCERIA", 1, 10, false, false);
                        $row['CDOPERINCLUSAO'] = isset($row['CDOPEREVOL']) ? $row['CDOPEREVOL'] : $this->environment->getCdOperador();
                        $row['NRCONTATO'] = $row['NRSEQCONTATO'];
                        $row['CDFILIAL'] = $this->environment->getCdFilial();
                        $row['IDLIGEXTPROS'] = 'S';
                        $row['IDPRIPUBPROS'] = 'V';

                        $edited = false;
                    } else {
                        if (isset($parcCriado['PROSPEXISTS']) && !$parcCriado['PROSPEXISTS']) {
                            $edited = false;
                            $row['__is_new'] = true;
                        } else {
                            $edited = true;
                            $row['__is_new'] = false;
                        }
                    }

                    $this->prospectService->setParceiroNegocio($row, !empty($parcCriado));
                    if (empty($parcCriado)) {
                        $this->prospectService->newContato($row);
                        $this->prospectService->createPartnership($row);
                    }
                } else {
                    $edited = true;
                    $this->util->setAuditColumns($row);
                }
                $verica = self::verificaModoRecebInfo($row);

                if (!$edited) {
                    parent::save($request, $response);
                    if (!empty($row['NRPARCRESPROSP'])) {
                        $this->updateProspectResponsavel($row);
                    }
                } else {
                    self::updateProspect($row);
                    if (!empty($row['NRPARCRESPROSP'])) {
                        $this->updateProspectResponsavel($row);
                    }
                }

                if (!empty($row['NRCONCORRENTE'])) {
                    if (empty($row['NRCONCORRPROSPECT'])) {
                        $row['NRCONCORRPROSPECT'] = NovoCodigo::geraCodigo($row['NRORG'], "CONCORRPROSPECT", 1, 5, false, true);
                        $this->prospectService->insertConcorrProspect($row);
                        $response->addDataSet(new DataSet("CONCORRENTE", array("NRCONCORRPROSPECT" => $row['NRCONCORRPROSPECT'])));
                    } else {
                        $this->prospectService->updateConcorrProspect($row);
                    }
                } else if (!empty($row['NRCONCORRPROSPECT'])) {
                    $this->prospectService->deleteConcorrProspect($row);
                    $response->addDataSet(new DataSet("CONCORRENTE", array("NRCONCORRPROSPECT" => null)));
                }

                if ($verica[0]["QUANTIDADE"] <= 0) {
                    self::setModoRecebInfo($row);
                } else {
                    self::updateModoRecebInfo($row);
                }
            }

            $this->prospectService->alteraAtivoStatusParc($row);

            $replicacao = $this->replicacao->replica($row['NRPARCNEGOCIO'], 'PROSPECT', 'PROSPECT', $row['__is_new']);
            $response->addDataSet(new DataSet("REPLICACAO", array($replicacao)));
            $response->addDataSet(new DataSet("DADOS", array(
                "PROSPECT" => $row['CDPROSPECT'],
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO']
            )));

            $this->connection->commit();
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
            $this->connection->rollBack();
        }
    }

    public function procedureMergeProspect(Row $row, Response $response)
    {
        $row = $row->getRow();

        $nrorg           = $row['NRORG'];
        $cdoperevol      = $row['CDOPEREVOL'];
        $nmprincipalparc = $row['PARCTOSTRING'];
        $nrparcnegocio   = $row['NRPARCNEGOCIO'];
        $retorno         = "";
        $retornoerro     = "";
        $procedureFundirProspect = new StoredProcedure($this->connection, "FUNDIR_PARCNEGOCIO_CRM");
        $procedureFundirProspect->addParam(new Param('P_PARCORIGEM', Param::PARAM_INPUT, $nmprincipalparc));
        $procedureFundirProspect->addParam(new Param('P_PARCNEGDESTINO', Param::PARAM_INPUT, $nrparcnegocio));
        $procedureFundirProspect->addParam(new Param('P_NRORG', Param::PARAM_INPUT, $nrorg));
        $procedureFundirProspect->addParam(new Param('P_CDOPERULTATU', Param::PARAM_INPUT, $cdoperevol));
        $procedureFundirProspect->addParam(new Param('P_RETORNO', Param::PARAM_OUTPUT, $retorno));
        $procedureFundirProspect->addParam(new Param('P_RETORNOERRO', Param::PARAM_OUTPUT, $retornoerro));

        try {
            $procedureFundirProspect->execute();
            $response->addDataSet(new DataSet("DADOS", array("RETORNO" => $retorno, "RETORNOERRO" => $retornoerro)));
        } catch (Exception $e) {
            $response->addDataSet(new DataSet("DADOS", array("RETORNOERRO" => "ERRO AO EXECUTAR A PROCEDURE")));
        }
    }

    public function verificaTarefas(Row $row, Response $response)
    {
        $row = $row->getRow();
        //$row['CDOPERADORLOGADO'] = $this->environment->getCdOperador();
        $retorno = $this->prospectService->verificaTarefas($row);
        $tarefas = array();
        if (is_array($retorno)) {
            foreach ($retorno as $tarefa) {
                $tarefa['NMOPERADOR'] = $this->prospectService->getOperador($tarefa['CDOPERREAL'], $row['NRORG']);
                if (!(in_array($tarefa['NMOPERADOR'], $tarefas)) && !empty($tarefa['NMOPERADOR']))
                    array_push($tarefas, $tarefa['NMOPERADOR']);
            }
        }
        if (empty($tarefas)) {
            $tarefas = false;
        }
        $response->addDataSet(new DataSet("DADOS", array("TAREFAS" => $tarefas)));
    }

    public function procedureInsertNextTaskProspect(Row $row, Response $response)
    {
        $row = $row->getRow();
        $retorno = $this->prospectService->prepareInsertProspectEvolutionNextTask($row);

        $response->addDataSet(new DataSet("DADOS", array("NRSEQFILACONTA" => $retorno)));

        if ($row["CDOPEREVOL"] != $row["CDOPERREAL"] && !empty($row["DSEMAILOPER"])) {

            $paramsEmail = array(
                "TIPO"                  => "",
                "NMOPERREAL"            => empty($row["NMOPERADORREAL"]) ? '' : $row["NMOPERADORREAL"],
                "OPERADORDOLOGADO"      => empty($row["NMOPERADOR"]) ? '' : $row["NMOPERADOR"],
                "DSTIPO"                => null,
                "DESCRICAO"             => null,
                "NRSEQCONTATO"          => null,
                "DSFILACONTATO"         => empty($row["DSFILACONTATO"]) ? '' : $row["DSFILACONTATO"],
                "NMPARCNEGOCIO"         => empty($row["NMPARCNEGOCIO"]) ? '' : $row["NMPARCNEGOCIO"],
                "DTPLANFILACONTA"       => empty($row["DTPLANFILACONTA"]) ? '' : $row["DTPLANFILACONTA"],
                "DTVENCFILACONTA"       => null,
                "DSCLASSIFICATAREFA"    => null,
                "DSDETEFILACONTA"       => null,
                "DSEMAILOPER"           => empty($row["DSEMAILOPER"]) ? '' : $row["DSEMAILOPER"]
            );

            $this->controlerNovaTarefa->enviaEmailTarefa($paramsEmail);
        }
    }

    public function selectContatoProspect(Row $row, Response $response)
    {
        $row = $row->getRow();
        $retorno = $this->prospectService->prepareSelectProspectContact($row);
        $response->addDataSet(new DataSet("DADOS", $retorno));
    }

    public function updateProspect($row)
    {
        $updateProspect = "UPDATE PROSPECT
                           SET IDTPIJURPROS = :IDTPIJURPROS,
                               IDQUALIFICADO = :IDQUALIFICADO,
                               NMFANTPROS = :NMFANTPROS,
                               IDPRIPUBPROS = :IDPRIPUBPROS,
                               CDMODODIVULG = :CDMODODIVULG,
                               CDATIVCLI = :CDATIVCLI,
                               CDQUALIF = :CDQUALIF,
                               NMRAZSOCPROS = :NMRAZSOCPROS,
                               NRINSJURPROS = :NRINSJURPROS,
                               NRPARCRESPROSP = :NRPARCRESPROSP,
                               CDEXPEDIENTE = :CDEXPEDIENTE,
                               CDSEGMER = :CDSEGMER,
                               IDATIVO = :IDATIVO,
                               VRFATUPROS = :VRFATUPROS,
                               NRFUNCPROS = :NRFUNCPROS,
                               IDSITUPROS = :IDSITUPROS,
                               DTNASCPROS = :DTNASCPROS,
                               HRINIFUNCPROSP = :HRINIFUNCPROSP,
                               HRFINFUNCPROSP = :HRFINFUNCPROSP,
                               IDLIGEXTPROS = :IDLIGEXTPROS,
                               NRUNOPPROS = :NRUNOPPROS,
                               DSCONCORREPROSP = :DSCONCORREPROSP,
                               DTENCECONTRATU = :DTENCECONTRATU,
                               DTREVPRECOPROSP = :DTREVPRECOPROSP,
                               NRPARCNEGOCIO = :NRPARCNEGOCIO,
                               NRSEQTPATIVCLI = :NRSEQTPATIVCLI,
                               NRINSESTPROS = :NRINSESTPROS,
                               DTULTATU        = :DTULTATU,
                               CDOPERULTATU    = :CDOPERULTATU,
                               NRORGULTATU     = :NRORGULTATU
                           WHERE CDPROSPECT = :CDPROSPECT 
                                 AND NRORG = :NRORG";

        $params = array(
            "IDTPIJURPROS"      => $row['IDTPIJURPROS'],
            "IDQUALIFICADO"     => $row['IDQUALIFICADO'],
            "NMFANTPROS"        => $row['NMFANTPROS'],
            "IDPRIPUBPROS"      => $row['IDPRIPUBPROS'],
            "CDMODODIVULG"      => $row['CDMODODIVULG'],
            "CDATIVCLI"         => $row['CDATIVCLI'],
            "CDQUALIF"          => $row['CDQUALIF'],
            "NMRAZSOCPROS"      => $row['NMRAZSOCPROS'],
            "NRINSJURPROS"      => $row['NRINSJURPROS'],
            "NRPARCRESPROSP"    => $row['NRPARCRESPROSP'],
            "CDEXPEDIENTE"      => $row['CDEXPEDIENTE'],
            "CDSEGMER"          => $row['CDSEGMER'],
            "IDATIVO"           => $row['IDATIVO'],
            "VRFATUPROS"        => $row['VRFATUPROS'],
            "NRFUNCPROS"        => $row['NRFUNCPROS'],
            "IDSITUPROS"        => $row['IDSITUPROS'],
            "DTNASCPROS"        => $row['DTNASCPROS'],
            "HRINIFUNCPROSP"    => $row['HRINIFUNCPROSP'],
            "HRFINFUNCPROSP"    => $row['HRFINFUNCPROSP'],
            "IDLIGEXTPROS"      => $row['IDLIGEXTPROS'],
            "NRUNOPPROS"        => $row['NRUNOPPROS'],
            "DSCONCORREPROSP"   => $row['DSCONCORREPROSP'],
            "DTENCECONTRATU"    => $row['DTENCECONTRATU'],
            "DTREVPRECOPROSP"   => $row['DTREVPRECOPROSP'],
            "NRPARCNEGOCIO"     => $row['NRPARCNEGOCIO'],
            "NRSEQTPATIVCLI"    => $row['NRSEQTPATIVCLI'],
            "CDPROSPECT"        => $row['CDPROSPECT'],
            "NRORG"             => $row['NRORG'],
            "NRINSESTPROS"      => $row['NRINSESTPROS'],
            'CDOPERULTATU'      =>  $row['CDOPERULTATU'],
            'NRORGULTATU'       =>  $row['NRORGULTATU'],
            'DTULTATU'          =>  $row['DTULTATU']
        );
        try {
            $std = $this->connection->prepare($updateProspect);
            $std->execute($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateProspectResponsavel($row)
    {
        try {
            $getOperador = "SELECT CDOPERADOR, NRPARCNEGOCIO FROM OPERADOR WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO AND NRORG = :NRORG AND ROWNUM = 1";
            $paramsOper = array(
                "NRPARCNEGOCIO" => $row['NRPARCRESPROSP'],
                "NRORG" => $row['NRORG']
            );

            $std1 = $this->connection->prepare($getOperador);
            $std1->execute($paramsOper);
            $operador = $std1->fetchAll();

            if (!empty($operador)) {
                $updateProspect = "UPDATE CRM_STATUSPARC
                                   SET NRPARCRESP = :NRPARCRESP,
                                       CDOPERRESP = :CDOPERRESP
                                   WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO 
                                         AND NRORG = :NRORG
                                         AND CRM_NRORGTRAB = :CRM_NRORGTRAB";

                $params = array(
                    "NRORG"             => $row['NRORG'],
                    "CRM_NRORGTRAB"     => $row['CRM_NRORGTRAB'],
                    "NRPARCNEGOCIO"     => $row['NRPARCNEGOCIO'],
                    "NRPARCRESP"        => $operador[0]['NRPARCNEGOCIO'],
                    "CDOPERRESP"        => $operador[0]['CDOPERADOR']
                );

                $std = $this->connection->prepare($updateProspect);
                $std->execute($params);
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function insertNrseqcontatoForNewOpportunity(Row $row)
    {

        $row = $row->getRow();

        $this->prospectService->callForInsertNrseqcontatoForNewOpportunity($row);
    }

    public function updatePartnerType(Row $row)
    {

        $row = $row->getRow();

        $this->prospectService->callForUpdatePartnerType($row);
    }

    public function insertPartnershipOfTypeClient(Row $row)
    {

        $row = $row->getRow();

        $this->prospectService->callForInsertPartnershipOfTypeClient($row);
    }

    public function insertClient(Row $request, Response $response)
    {
        try {
            $row = $request->getRow();
            $razSocial;
            $parceiro;

            $row['INSCRICAO'] = $row['NRINSJURPROS'];
            if (empty($row['IDTPIJURPROS'])) {
                $parceiro = $this->prospectService->getProspect($row);
                if (empty($parceiro)) {
                    $parceiro = $this->prospectService->getLead($row);
                }
                $row = $this->buildNewRow($parceiro, $row);
            }
            $row['IDTPIJURCAN'] = $row['IDTPIJURPROS'];

            $this->connection->beginTransaction();

            $cliente = $this->prospectService->verificaCliente($row['NRPARCNEGOCIO'], $row['NRORG'], $row['NRINSJURPROS']);

            if (!empty($cliente)) {
                if (!empty($cliente[0])) {
                    $clienteNr = $cliente[0][0];
                }
                if (!empty($cliente[1])) {
                    $clienteInsc = $cliente[1][0];
                }

                if (isset($clienteInsc) && $row['NRPARCNEGOCIO'] != $clienteInsc['NRPARCNEGOCIO']) {
                    if (empty($clienteInsc['NRPARCNEGOCIO'])) {
                        $this->prospectService->updateClientWithoutNrParcNegocio($clienteInsc);
                        $row['PARCORIGINAL'] = $row['NRPARCNEGOCIO'];
                        $row['NRPARCNEGOCIO'] = $clienteInsc['NRPARCNEGOCIO'];
                        $row['NRPARCRESP'] = $row['NRPARCRESPROSP'];
                        $row['CDOPERRESPONSAVEL'] = $row['CDOPERADOR'];
                        $row['IDSTATUS'] = null;
                        $row['CDCLIENTE'] = $clienteInsc["CDCLIENTE"];
                        $row['CDTIPOPARCEIRO'] = 'CLIENTE';
                        $razSocial = $clienteNr['NMRAZSOCCLIE'];

                        $this->prospectService->fundeParceiro($row);
                        $this->prospectService->desativarStatusParc($row);
                        $this->prospectService->insertStatus($row);
                    } else {
                        $row['PARCORIGINAL'] = $row['NRPARCNEGOCIO'];
                        $row['NRPARCNEGOCIO'] = $clienteInsc['NRPARCNEGOCIO'];
                        $row['NRPARCRESP'] = $row['NRPARCRESPROSP'];
                        $row['CDOPERRESPONSAVEL'] = $row['CDOPERADOR'];
                        $row['IDSTATUS'] = null;
                        $row['CDCLIENTE'] = $clienteInsc["CDCLIENTE"];
                        $row['CDTIPOPARCEIRO'] = 'CLIENTE';
                        $razSocial = $clienteInsc['NMRAZSOCCLIE'];

                        $this->prospectService->fundeParceiro($row);
                        $this->prospectService->desativarStatusParc($row);
                        $this->prospectService->insertStatus($row);
                    }
                } else if (isset($clienteNr)) {
                    $this->prospectService->updateStatusClie($row);
                    $razSocial = $clienteNr['NMRAZSOCCLIE'];
                } else {
                    if (empty($row['CDCLIENTE'])) {
                        $row['CDCLIENTE'] = $this->newCode->getCodeByTableName("CLIENTE", $row["NRORG"]);
                    }
                    $this->prospectService->callForUpdatePartnerType($row);
                    $this->prospectService->callForInsertPartnershipOfTypeClient($row);
                    $this->prospectService->callForInsertClient($row);
                    $this->prospectService->callForInsertAllAddresses($row);
                    $this->prospectService->callForDeactivateProspect($row);
                    $this->prospectService->updateStatusClie($row);
                }
            } else {
                if (empty($row['CDCLIENTE'])) {
                    $row['CDCLIENTE'] = $this->newCode->getCodeByTableName("CLIENTE", $row["NRORG"]);
                }
                $this->prospectService->callForUpdatePartnerType($row);
                $this->prospectService->callForInsertPartnershipOfTypeClient($row);
                $this->prospectService->callForInsertClient($row);
                $this->prospectService->callForInsertAllAddresses($row);
                $this->prospectService->callForDeactivateProspect($row);
                $this->prospectService->updateStatusClie($row);
            }

            $returnArray = array(
                "CDCLIENTE" => $row['CDCLIENTE']
            );

            $response->addDataSet(new DataSet('DADOS', $returnArray));
            if (!empty($razSocial)) {
                $response->addDataSet(new DataSet('CLIENTE', array($razSocial)));
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
            $this->connection->rollBack();
        }
    }

    public function deactivateProspect(Row $row)
    {

        $row = $row->getRow();

        $this->prospectService->callForDeactivateProspect($row);
    }

    public function insertClientAddress(Row $row)
    {

        $row = $row->getRow();

        $this->prospectService->callForInsertClientAddress($row);
    }

    public function selectProspectAddress(Row $row, Response $response)
    {

        $row = $row->getRow();

        $returnedAddress = $this->prospectService->callForSelectAddressProspect($row);

        $response->addDataSet(new DataSet("DADOS", array("ADDRESS" => $returnedAddress)));
    }

    public function setTaskEndDate(Row $row)
    {

        $row = $row->getRow();

        $this->prospectService->callForSetTaskEndDate($row);
    }

    public function deactivateProspectTask(Row $row)
    {

        $row = $row->getRow();

        $taskUpdateParams = array(

            "NRSEQFILACONTA"    => $row["NRSEQFILACONTA"]

        );

        $this->prospectService->callForDeactivateProspectTask($taskUpdateParams);
    }

    public function convertInClient(Row $row, DTO\Response $response)
    {
        try {
            $row = $row->getRow();

            $nrparcnegocio = $this->parceiroService->replicaParceiro($row);

            if ($row['__is_new']) {
                $response->addDataset(new DataSet('columnsToReturn', array("NRPARCNEGOCIO" => $nrparcnegocio)));
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function replicaInterlocutorProspect(Row $row, DTO\Response $response)
    {
        $row = $row->getRow();

        if (!$row['__is_new']) {
            $this->prospectService->replicaInterlocutorProspect($row);
        }
    }

    public function setIdQualificadoProspect(Row $row)
    {
        $row = $row->getRow();

        $this->prospectService->setIdQualificadoProspect($row);
    }

    public function validaCNPJCliente(Row $row, Response $response)
    {

        $row = $row->getRow();

        $returnedClientes = $this->prospectService->validaCNPJCliente($row);

        $response->addDataSet(new DataSet("cnpjcliente", array("valid" => $returnedClientes)));
    }

    public function setModoRecebInfo($row)
    {

        $insertModo = "INSERT INTO GER_PARCNEGOCIOINFO (NRPARCNEGOCIO, NRORG, NRMODORECEBINFO)
         VALUES (:NRPARCNEGOCIO,
                 :NRORG,
                 :NRMODORECEBINFO)";

        $params = array(
            "NRPARCNEGOCIO"         => (int)$row["NRPARCNEGOCIO"],
            "NRORG"                 => $row["NRORG"],
            "NRMODORECEBINFO"       => $row["NRMODORECEBINFO"]
        );

        try {
            $std = $this->entityManager->getConnection()->prepare($insertModo);
            $std->execute($params);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        };
    }

    public function updateModoRecebInfo($row)
    {


        $updatemodorecebeinfo = "UPDATE GER_PARCNEGOCIOINFO
                                 SET NRMODORECEBINFO = :NRMODORECEBINFO
                                 WHERE NRPARCNEGOCIO = :NRPARCNEGOCIO AND
                                 NRORG = :NRORG";
        $params = array(
            "NRMODORECEBINFO" => $row['NRMODORECEBINFO'],
            "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
            "NRORG" => $row['NRORG']
        );
        try {
            $std = $this->connection->prepare($updatemodorecebeinfo);
            $std->execute($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function verificaModoRecebInfo($row)
    {

        $verificamodorecebinfo = "SELECT COUNT(NRPARCNEGOCIO) QUANTIDADE FROM GER_PARCNEGOCIOINFO where NRPARCNEGOCIO  =  :NRPARCNEGOCIO";

        $params = array(
            "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],

        );
        try {
            $std = $this->connection->prepare($verificamodorecebinfo);
            $std->execute($params);
            $retornoModoRecebInfo = $std->fetchAll();
            return $retornoModoRecebInfo;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function checkCanEditEvol(Row $request, Response $response)
    {
        $row = $request->getRow();
        $canEdit;

        // Verifica se o parâmetro que permite editar evoluções de outros
        //operadores está ativado.
        $paramEditEvolActive = $this->prospectService->isParamOperDifEditEvolActive($row);


        if ($paramEditEvolActive) {
            $canEdit = true;
        } else {
            // Verifica se o operador que está tentando editar a evolução é
            //o mesmo que a criou.
            $sameOper = $this->prospectService->operToEditIsTheSame($row);

            $canEdit = $sameOper;
        }

        $response->addDataSet(new DataSet("DATA", array("CAN_EDIT" => $canEdit)));
    }


    public function pesquisaParceiro(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $result = $this->prospectService->pesquisaParceiro($request->getFilterCriteria()->getConditions());
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('parcnegocio_search', $result));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function buildNewRow($parceiro, $row)
    {
        $newRow = array();
        $caseSwitch = isset($parceiro['NRINSJURPROS']) ? 'prospect' : 'lead';

        switch ($caseSwitch) {
            case 'prospect':
                //Dados principais
                $newRow['CDPROSPECT']        = $parceiro['CDPROSPECT'];
                $newRow['NMFANTPROS']        = $parceiro['NMFANTPROS'];
                $newRow['NMRAZSOCPROS']      = $parceiro['NMRAZSOCPROS'];
                $newRow['NRINSJURPROS']      = $parceiro['NRINSJURPROS'];
                $newRow['IDTPIJURPROS']      = $parceiro['IDTPIJURPROS'];
                $newRow['NRPARCNEGOCIO']     = $parceiro['NRPARCNEGOCIO'];
                $newRow['NRINSESTPROS']      = $parceiro['NRINSESTPROS'];
                $newRow['CDQUALIF']          = $parceiro['CDQUALIF'];
                $newRow['IDATIVO']           = $parceiro['IDATIVO'];
                $newRow['NRORG']             = $row['NRORG'];
                $newRow['CRM_NRORGTRAB']     = $row['CRM_NRORGTRAB'];
                $newRow['CDOPERADOR']        = $parceiro['CDOPERADOR'];

                //Dados secundários
                $newRow['CDMODODIVULG']      = $parceiro['CDMODODIVULG'];
                $newRow['CDATIVCLI']         = '';
                $newRow['NRSEQTPATIVCLI']    = $parceiro['NRSEQTPATIVCLI'];
                $newRow['CDSEGMER']          = $parceiro['CDSEGMER'];
                $newRow['IDPRIPUBPROS']      = $parceiro['IDPRIPUBPROS'];
                $newRow['CDEXPEDIENTE']      = $parceiro['CDEXPEDIENTE'];
                $newRow['DSHOPAPROS']        = $parceiro['DSHOPAPROS'];
                $newRow['VRFATUPROS']        = $parceiro['VRFATUPROS'];
                $newRow['NRFUNCPROS']        = $parceiro['NRFUNCPROS'];
                $newRow['IDSITUPROS']        = $parceiro['IDSITUPROS'];
                $newRow['DTNASCPROS']        = $parceiro['DTNASCPROS'];
                $newRow['HRINIFUNCPROSP']    = $parceiro['HRINIFUNCPROSP'];
                $newRow['HRFINFUNCPROSP']    = $parceiro['HRFINFUNCPROSP'];
                $newRow['IDLIGEXTPROS']      = $parceiro['IDLIGEXTPROS'];
                $newRow['NRUNOPPROS']        = $parceiro['NRUNOPPROS'];
                $newRow['DSCONCORREPROSP']   = $parceiro['DSCONCORREPROSP'];
                $newRow['DTENCECONTRATU']    = $parceiro['DTENCECONTRATU'];
                $newRow['DTREVPRECOPROSP']   = $parceiro['DTREVPRECOPROSP'];
                $newRow['IDPARCFUNDIDO']     = $parceiro['IDPARCFUNDIDO'];

                //Endereço
                $newRow['CDPAIS']            = $parceiro['CDPAIS'];
                $newRow['SGESTADO']          = $parceiro['SGESTADO'];
                $newRow['CDMUNICIPIO']       = $parceiro['CDMUNICIPIO'];
                $newRow['CDBAIRRO']          = $parceiro['CDBAIRRO'];
                $newRow['NRCEPENDERECO']     = $parceiro['NRCEPENDERECO'];
                $newRow['DSENDERECO']        = $parceiro['DSENDERECO'];
                $newRow['NRIMOVELENDERECO']  = $parceiro['NRIMOVELENDERECO'];
                $newRow['DSCOMPLEENDERECO']  = $parceiro['DSCOMPLEENDERECO'];

                //Auditoria
                $newRow['NRORGINCLUSAO']     = $row['NRORG'];
                $newRow['DTINCLUSAO']        = $row['DTINCLUSAO'];
                $newRow['CDOPERINCLUSAO']    = $row['CURRENTOPER'];
                $newRow['DTULTATU']          = $row['DTINCLUSAO'];
                $newRow['CDOPERULTATU']      = $row['CURRENTOPER'];
                break;
            case 'lead':
                //Dados principais
                $newRow['NMFANTPROS']        = $parceiro['NMCANDIDATO'];
                $newRow['NMRAZSOCPROS']      = $parceiro['NMFANTCAN'];
                $newRow['NRINSJURPROS']      = $parceiro['NRINSJURCAN'];
                $newRow['IDTPIJURPROS']      = $parceiro['IDTPIJURCAN'];
                $newRow['NRPARCNEGOCIO']     = $parceiro['NRPARCNEGOCIO'];
                $newRow['NRINSESTPROS']      = '';
                $newRow['CDQUALIF']          = '';
                $newRow['IDATIVO']           = 'S';
                $newRow['NRORG']             = $row['NRORG'];
                $newRow['CRM_NRORGTRAB']     = $row['CRM_NRORGTRAB'];
                $newRow['CDOPERADOR']        = $parceiro['CDOPERADOR'];

                //Dados secundários
                $newRow['CDMODODIVULG']      = $parceiro['CDMODODIVULG'];
                $newRow['CDATIVCLI']         = '';
                $newRow['NRSEQTPATIVCLI']    = '';
                $newRow['CDSEGMER']          = $parceiro['CDSEGMER'];
                $newRow['IDPRIPUBPROS']      = '';
                $newRow['CDEXPEDIENTE']      = '';
                $newRow['DSHOPAPROS']        = '';
                $newRow['VRFATUPROS']        = '';
                $newRow['NRFUNCPROS']        = '';
                $newRow['IDSITUPROS']        = 'A';
                $newRow['DTNASCPROS']        = '';
                $newRow['HRINIFUNCPROSP']    = '';
                $newRow['HRFINFUNCPROSP']    = '';
                $newRow['IDLIGEXTPROS']      = '';
                $newRow['NRUNOPPROS']        = '';
                $newRow['DSCONCORREPROSP']   = '';
                $newRow['DTENCECONTRATU']    = '';
                $newRow['DTREVPRECOPROSP']   = '';
                $newRow['IDPARCFUNDIDO']     = $parceiro['IDPARCFUNDIDO'];

                //Endereço
                $newRow['CDPAIS']            = $parceiro['CDPAIS'];
                $newRow['SGESTADO']          = $parceiro['SGESTADO'];
                $newRow['CDMUNICIPIO']       = $parceiro['CDMUNICIPIO'];
                $newRow['CDBAIRRO']          = $parceiro['CDBAIRRO'];
                $newRow['NRCEPENDERECO']     = $parceiro['NRCEPENDERECO'];
                $newRow['DSENDERECO']        = $parceiro['DSENDERECO'];
                $newRow['NRIMOVELENDERECO']  = $parceiro['NRIMOVELENDERECO'];
                $newRow['DSCOMPLEENDERECO']  = $parceiro['DSCOMPLEENDERECO'];

                //Auditoria
                $newRow['NRORGINCLUSAO']     = $row['NRORG'];
                $newRow['DTINCLUSAO']        = $row['DTINCLUSAO'];
                $newRow['CDOPERINCLUSAO']    = $row['CURRENTOPER'];
                $newRow['DTULTATU']          = $row['DTINCLUSAO'];
                $newRow['CDOPERULTATU']      = $row['CURRENTOPER'];
                break;
        }

        return $newRow;
    }
}
