<?php

namespace Teknisa\CRM\Service;

use DateTime;

class AgrupamentoParceiroService
{

    protected $agrupamentoParceiroFactory;

    public function __construct($agrupamentoParceiroFactory)
    {

        $this->agrupamentoParceiroFactory = $agrupamentoParceiroFactory;
    }


    public function executeDeleteGroup($row)
    {
        $paramsQuery = array(
            "NRAGRPARC"        => $row['NRAGRPARC'],
            "CRM_NRORGTRAB"    => $row['CRM_NRORGTRAB'],
            "NRORG"            => $row['NRORG']
        );

        $this->agrupamentoParceiroFactory->queryDeleteGroup($paramsQuery);
    }

    public function verifyGroup($row)
    {
        $response = array();

        $paramsQuery = array(
            "NRPARCNEGOCIO_REL" => $row['NRPARCNEGOCIO'],
            "CRM_NRORGTRAB"     => $row['CRM_NRORGTRAB'],
            "NRORG"             => $row['NRORG']
        );

        $response = $this->agrupamentoParceiroFactory->verifyGroup($paramsQuery);

        if (!empty($response)) {
            return array($response, 'PPR');         //Parceiro-Pai Relacionado
        } else {
            $paramsQueryRel = array(
                "NRPARCNEGOCIO_REL"  => $row['NRPARCNEGOCIO_REL'],
                "CRM_NRORGTRAB"      => $row['CRM_NRORGTRAB'],
                "NRORG"              => $row['NRORG']
            );

            $response = $this->agrupamentoParceiroFactory->verifyGroup($paramsQueryRel);

            if (!empty($response)) {
                return array($response, 'PFR');     //Parceiro-Filho Relacionado
            } else {
                return false;                       //Retorna falso se caso todas as verificações não acharem uma relação
            }
        }
    }

    public function insertTaskRel($row)
    {
        try {
            $paramsQuery = array(
                "NRSEQFILACONTA" => $row['NRSEQFILACONTA'],
                "NRSEQCONTATO" => $row['NRSEQCONTATO'],
                "DSFILACONTATO" => $row['DSFILACONTATO'],
                "DTPLANFILACONTA" => $row['DTPLANFILACONTA'],
                "CDOPERREAL" => $row['CDOPERREAL'],
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                "IDORIGFILACONTA" => $row['IDORIGFILACONTA'],
                "NRPRIORFILACONT" => $row['NRPRIORFILACONT'],
                "NRORG" => $row['NRORG'],
                "CRM_NRORGTRAB" => $row['CRM_NRORGTRAB'],
                "NRSEQCAMPANHA" => $row['NRSEQCAMPANHA']
            );

            $this->agrupamentoParceiroFactory->insertTaskRel($paramsQuery);
            return "ok";
        } catch (\Exception $e) {
            $e->getMessage();
            throw new \Exception($e);
        }
    }

    public function verifyGroupRel($row)
    {
        $response = array();

        $paramsQuery = array(
            "NRPARCNEGOCIO_REL" => $row['NRPARCNEGOCIO'],
            "CRM_NRORGTRAB"     => $row['CRM_NRORGTRAB'],
            "NRORG"             => $row['NRORG']
        );

        return $this->agrupamentoParceiroFactory->verifyGroup($paramsQuery);
    }

    public function agrupamentoEvolSave($row)
    {
        $txtevolcont = empty($row['TXEVOLCONT']) ? $row['TXEVOLCONT'] : 'Evolução de realizada a partir da conversão do Parceiro Relacionado Pai.';


        $paramsQuery = array(
            "NRCONTATO"         => $row['NRCONTATO'],
            "DTHREVOLCONT"      => !empty($row['DTHREVOLCONT']) ? $row['DTHREVOLCONT'] : $row['DTINCLUSAO'],
            "CDTIPOCONT"        => !empty($row['CDTIPOCONT']) ? $row['CDTIPOCONT'] : null,
            "IDSENEVOCONT"      => !empty($row['IDSENEVOCONT']) ? $row['IDSENEVOCONT'] : 'S',
            "CDOPEREVOL"        => !empty($row['CDOPEREVOL']) ? $row['CDOPEREVOL'] : $row['CDOPERADOR'],
            "CDMOTIEVOCON"      => !empty($row['CDMOTIEVOCON']) ? $row['CDMOTIEVOCON'] : null,
            "NRORG"             => $row['NRORG'],
            "CRM_NRORGTRAB"     => $row['CRM_NRORGTRAB'],
            "TXEVOLCONT"        => $txtevolcont,
            "NRSEQRESULEVOL"    => !empty($row['NRSEQRESULEVOL']) ? $row['NRSEQRESULEVOL'] : null,
            "NRSEQEVOLCONT"     => $row['NRSEQEVOLCONT'],
            "NRSEQCONTATO"      => $row['NRSEQCONTATO'],
            "CDFILIAL"          => isset($row['CDFILIAL']) ? $row['CDFILIAL'] : null
        );

        $this->agrupamentoParceiroFactory->agrupamentoEvolSave($paramsQuery);
    }

    public function verifyParcGroupRel($row)
    {
        $resp = array();

        $paramsQuery = array(
            "NRPARCNEGOCIO"     => $row['NRPARCNEGOCIO'],
            "CRM_NRORGTRAB"     => $row['CRM_NRORGTRAB'],
            "NRORG"             => $row['NRORG']
        );

        $resp[] = $this->agrupamentoParceiroFactory->verifyParcGroupRel($paramsQuery);

        $resp[] = $this->agrupamentoParceiroFactory->searchParcnegocio($paramsQuery);

        return $resp;
    }

    public function searchNrContato($row)
    {
        $paramsQuery = array(
            "NRPARCNEGOCIO"     => $row['NRPARCNEGOCIO'],
            "NRORG"             => $row['NRORG']
        );

        return $this->agrupamentoParceiroFactory->searchNrContato($paramsQuery);
    }

    public function getRelationshipPartnerStatus($row)
    {
        try {
            $paramsQuery = array(
                "NRPARCNEGOCIO"     => $row['NRPARCNEGOCIO'],
                "CRM_NRORGTRAB"     => $row['CRM_NRORGTRAB'],
                "NRORG"             => $row['NRORG']
            );

            $this->agrupamentoParceiroFactory->getRelationshipPartnerStatus($paramsQuery);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function setRelationshipPartnerStatus($row, $status)
    {
        try {
            $paramsQuery = array(
                "NRPARCNEGOCIO"     => $row['NRPARCNEGOCIO'],
                "CRM_NRORGTRAB"     => $row['CRM_NRORGTRAB'],
                "NRORG"             => $row['NRORG'],
                "STATUSPARC"        => $status
            );

            $this->agrupamentoParceiroFactory->setRelationshipPartnerStatus($paramsQuery);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function newFilterService($filterValues)
    {
        try {
            foreach ($filterValues as $filter) {
                $outputArray[$filter["columnName"]] = $filter["value"];
            }

            if (isset($outputArray['DTHREVOLCONT'])) {
                $dateRange = $outputArray['DTHREVOLCONT'];
                $formattedDates = array_map(function ($date) {
                    return DateTime::createFromFormat('d/m/Y', $date)->format('Y-m-d');
                }, $dateRange);

                $initialDate = $formattedDates[0];
                $finalDate = $formattedDates[1];
            }

            $paramsQuery = array(
                "IDTPOPERADOR"      => $outputArray['IDTPOPERADOR'],
                "NOMEPRINCIPAL"     => !empty($outputArray['NOMEPRINCIPAL']) ? $outputArray['NOMEPRINCIPAL'] : null,
                "NOMEFANTASIA"      => !empty($outputArray['NOMEFANTASIA']) ? $outputArray['NOMEFANTASIA'] : null,
                "STATUS"            => !empty($outputArray['STATUS']) ? $outputArray['STATUS'] : null,
                "INSCRICAO"         => !empty($outputArray['INSCRICAO']) ? $outputArray['INSCRICAO'] : null,
                "IDATIVO"           => !empty($outputArray['IDATIVO']) ? $outputArray['IDATIVO'] : null,
                "NRORGTRAB"         => $outputArray['CRM_NRORGTRAB'],
                "CRM_NRORGTRAB"     => $outputArray['CRM_NRORGTRAB'],
                "CDPAIS"            => isset($outputArray['CDPAIS']) ? $outputArray['CDPAIS'] : null,
                "SGESTADO"          => !empty($outputArray['SGESTADO']) ? $outputArray['SGESTADO'] : null,
                "CDMUNICIPIO"       => !empty($outputArray['CDMUNICIPIO']) ? $outputArray['CDMUNICIPIO'] : null,
                "CDBAIRRO"          => !empty($outputArray['CDBAIRRO']) ? $outputArray['CDBAIRRO'] : null,
                "CDSEGMER"          => !empty($outputArray['CDSEGMER']) ? $outputArray['CDSEGMER'] : null,
                "CDATIVCLI"         => !empty($outputArray['CDSEGMER']) ? $outputArray['CDSEGMER'] : null,
                "POSSUIEVOLUCOES"   => !empty($outputArray['POSSUIEVOLUCOES']) ? $outputArray['POSSUIEVOLUCOES'] : null,
                "POSSUITAREFAS"     => !empty($outputArray['POSSUITAREFAS']) ? $outputArray['POSSUITAREFAS'] : null,
                "DIASULTEVOL"       => !empty($outputArray['DIASULTEVOL']) ? $outputArray['DIASULTEVOL'] : null,
                "DIASULTATIVCONC"   => !empty($outputArray['DIASULTATIVCONC']) ? $outputArray['DIASULTATIVCONC'] : null,
                "CDMODODIVULG"      => !empty($outputArray['CDSEGMCDMODODIVULGER']) ? $outputArray['CDMODODIVULG'] : null,
                "TIPOPARCEIRO"      => !empty($outputArray['TIPOPARCEIRO']) ? $outputArray['TIPOPARCEIRO'] : null,
                "DTINICIAL"         => isset($initialDate) ? $initialDate : null,
                "DTFIM"             => isset($finalDate)   ? $finalDate : null,
                "IDSENEVOCONT"      => !empty($outputArray['IDSENEVOCONT']) ? $outputArray['IDSENEVOCONT'] : null,
                "NRPARCRESPONSAVEL" => !empty($outputArray['NRPARCRESPONSAVEL']) ? $outputArray['NRPARCRESPONSAVEL'] : null,
                "CDTIPOCONT"        => !empty($outputArray['CDTIPOCONT']) ? $outputArray['CDTIPOCONT'] : null,
                "CDMOTIEVOCON"      => !empty($outputArray['CDMOTIEVOCON']) ? $outputArray['CDMOTIEVOCON'] : null,
                "NRSEQRESULEVOL"    => !empty($outputArray['NRSEQRESULEVOL']) ? $outputArray['NRSEQRESULEVOL'] : null,
                "TXEVOLCONT"        => !empty($outputArray['TXEVOLCONT']) ? $outputArray['TXEVOLCONT'] : null
            );

            return $this->agrupamentoParceiroFactory->findNewFilterCriteriaFactory(array($paramsQuery));
        } catch (\Exception $e) {
            throw $e;
        }
    }
}
